/* ide-posix.h
 *
 * Copyright (C) 2016 Christian Hergert <chergert@redhat.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef IDE_POSIX_H
#define IDE_POSIX_H

#include <glib.h>

G_BEGIN_DECLS

gchar       *ide_get_system_arch      (void);
const gchar *ide_get_system_type      (void);
gsize        ide_get_system_page_size (void) G_GNUC_CONST;
gchar       *ide_path_collapse        (const gchar *path);
gchar       *ide_path_expand          (const gchar *path);

G_END_DECLS

#endif /* IDE_POSIX_H */
